@@ -710,7 +710,7 @@ fn impl_checkout_server(ast: &DeriveInput) -> TokenStream {
         impl #impl_generics checkout_server::Server<#common_lifetime, #context_type_name #ty_generics> for #server_type_name {
             type Context = checkout_server::ServerContext;
 
-            fn api_description() -> checkout_server::ApiDescription<checkout_server::ServerContext> {
+            fn api_description() -> checkout_server::ApiDescription<()> {
                 let mut api = checkout_server::ApiDescription::new();
                 api.register(checkout_server::create_endpoint).unwrap();
                 api.register(checkout_server::add_item_endpoint).unwrap();
